Change in osmo-bsc[master]: assignment_fsm: only include speech codec (choosen) on AoIP networks

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

Harald Welte gerrit-no-reply at lists.osmocom.org
Mon Sep 24 11:14:30 UTC 2018


Harald Welte has submitted this change and it was merged. ( https://gerrit.osmocom.org/11059 )

Change subject: assignment_fsm: only include speech codec (choosen) on AoIP networks
......................................................................

assignment_fsm: only include speech codec (choosen) on AoIP networks

The field speech codec (choosen) in the ASSIGNMENT COMPLETE message
has been specified with AoIP. Since sccp-lite has been specified before
AoIP, we should not include the speech codec (choosen) field in the
ASSIGNMENT COMPLETE, when osmo-bsc is connected to an sccp-lite based
network.

- make sure speech codec (choosen) is only included on AoIP based
  networks

Change-Id: Ic7f28aacc953d96ebf3aa04f3e1810475458c1a8
---
M src/osmo-bsc/assignment_fsm.c
1 file changed, 8 insertions(+), 4 deletions(-)

Approvals:
  Jenkins Builder: Verified
  Harald Welte: Looks good to me, approved



diff --git a/src/osmo-bsc/assignment_fsm.c b/src/osmo-bsc/assignment_fsm.c
index 63776f0..5304d6c 100644
--- a/src/osmo-bsc/assignment_fsm.c
+++ b/src/osmo-bsc/assignment_fsm.c
@@ -165,10 +165,14 @@
 			addr_local_p = &addr_local;
 		}
 
-		/* Extrapolate speech codec from speech mode */
-		/* FIXME: AMR codec configuration must be derived from lchan1! */
-		gsm0808_speech_codec_from_chan_type(&sc, perm_spch);
-		sc_ptr = ≻
+		/* Only AoIP networks include a speech codec (choosen) in the
+		 * assignment complete message. */
+		if (gscon_is_aoip(conn)) {
+			/* Extrapolate speech codec from speech mode */
+			/* FIXME: AMR codec configuration must be derived from lchan1! */
+			gsm0808_speech_codec_from_chan_type(&sc, perm_spch);
+			sc_ptr = ≻
+		}
 	}
 
 	resp = gsm0808_create_ass_compl(lchan->abis_ip.ass_compl.rr_cause,

-- 
To view, visit https://gerrit.osmocom.org/11059
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-MessageType: merged
Gerrit-Change-Id: Ic7f28aacc953d96ebf3aa04f3e1810475458c1a8
Gerrit-Change-Number: 11059
Gerrit-PatchSet: 3
Gerrit-Owner: dexter <pmaier at sysmocom.de>
Gerrit-Reviewer: Harald Welte <laforge at gnumonks.org>
Gerrit-Reviewer: Jenkins Builder (1000002)
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20180924/ff714ae9/attachment.htm>


More information about the gerrit-log mailing list